# mypy-boto3-kinesis

[![PyPI - mypy-boto3-kinesis](https://img.shields.io/pypi/v/mypy-boto3-kinesis.svg?color=blue)](https://pypi.org/project/mypy-boto3-kinesis)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-kinesis.svg?color=blue)](https://pypi.org/project/mypy-boto3-kinesis)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

Type annotations for
[boto3.Kinesis 1.14.58](https://boto3.amazonaws.com/v1/documentation/api/1.14.58/reference/services/kinesis.html#Kinesis) service
compatible with
[VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright)
and other tools.

Generated by [mypy-boto3-buider 3.0.4](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

- [mypy-boto3-kinesis](#mypy-boto3-kinesis)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Service Resource annotations](#service-resource-annotations)
    - [Other resources annotations](#other-resources-annotations)
    - [Collections annotations](#collections-annotations)
    - [Typed dictionations](#typed-dictionations)

## How to install

Install `boto3-stubs` for `Kinesis` service.

```bash
python -m pip install boto3-stubs[kinesis]
```

## Usage

### VSCode

- Install [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[kinesis]` in your environment: `python -m pip install 'boto3-stubs[kinesis]'`

Both type checking and auto-complete should work for `Kinesis` service.
No explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[kinesis]` in your environment: `python -m pip install 'boto3-stubs[kinesis]'`

Both type checking and auto-complete should work for `Kinesis` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed `boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[kinesis]` in your environment: `python -m pip install 'boto3-stubs[kinesis]'`
- Run `mypy` as usual

Type checking should work for `Kinesis` service.
No explicit type annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[kinesis]` in your environment: `python -m pip install 'boto3-stubs[kinesis]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Kinesis` service.
No explicit type annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`KinesisClient` provides annotations for `boto3.client("kinesis")`.

```python
import boto3

from mypy_boto3_kinesis import KinesisClient

client: KinesisClient = boto3.client("kinesis")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: KinesisClient = session.client("kinesis")
```

### Paginators annotations

`mypy_boto3_kinesis.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_kinesis import KinesisClient
from mypy_boto3_kinesis.paginator import (
    DescribeStreamPaginator,
    ListShardsPaginator,
    ListStreamConsumersPaginator,
    ListStreamsPaginator,
)

client: KinesisClient = boto3.client("kinesis")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
describe_stream_paginator: DescribeStreamPaginator = client.get_paginator("describe_stream")
list_shards_paginator: ListShardsPaginator = client.get_paginator("list_shards")
list_stream_consumers_paginator: ListStreamConsumersPaginator = client.get_paginator("list_stream_consumers")
list_streams_paginator: ListStreamsPaginator = client.get_paginator("list_streams")
```


### Waiters annotations

`mypy_boto3_kinesis.waiter` module contains type annotations for all waiters.

```python
from mypy_boto3_kinesis import KinesisClient
from mypy_boto3_kinesis.waiter import StreamExistsWaiter, StreamNotExistsWaiter

client: KinesisClient = boto3.client("kinesis")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
stream_exists_waiter: StreamExistsWaiter = client.get_waiter("stream_exists")
stream_not_exists_waiter: StreamNotExistsWaiter = client.get_waiter("stream_not_exists")
```





### Typed dictionations

`mypy_boto3_kinesis.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_kinesis.type_defs import (
    ChildShardTypeDef,
    ConsumerDescriptionTypeDef,
    ConsumerTypeDef,
    DescribeLimitsOutputTypeDef,
    DescribeStreamConsumerOutputTypeDef,
    DescribeStreamOutputTypeDef,
    DescribeStreamSummaryOutputTypeDef,
    EnhancedMetricsTypeDef,
    EnhancedMonitoringOutputTypeDef,
    GetRecordsOutputTypeDef,
    GetShardIteratorOutputTypeDef,
    HashKeyRangeTypeDef,
    InternalFailureExceptionTypeDef,
    KMSAccessDeniedExceptionTypeDef,
    KMSDisabledExceptionTypeDef,
    KMSInvalidStateExceptionTypeDef,
    KMSNotFoundExceptionTypeDef,
    KMSOptInRequiredTypeDef,
    KMSThrottlingExceptionTypeDef,
    ListShardsOutputTypeDef,
    ListStreamConsumersOutputTypeDef,
    ListStreamsOutputTypeDef,
    ListTagsForStreamOutputTypeDef,
    PaginatorConfigTypeDef,
    PutRecordOutputTypeDef,
    PutRecordsOutputTypeDef,
    PutRecordsRequestEntryTypeDef,
    PutRecordsResultEntryTypeDef,
    RecordTypeDef,
    RegisterStreamConsumerOutputTypeDef,
    ResourceInUseExceptionTypeDef,
    ResourceNotFoundExceptionTypeDef,
    SequenceNumberRangeTypeDef,
    ShardFilterTypeDef,
    ShardTypeDef,
    StartingPositionTypeDef,
    StreamDescriptionSummaryTypeDef,
    StreamDescriptionTypeDef,
    SubscribeToShardEventStreamTypeDef,
    SubscribeToShardEventTypeDef,
    SubscribeToShardOutputTypeDef,
    TagTypeDef,
    UpdateShardCountOutputTypeDef,
    WaiterConfigTypeDef,
)

def get_structure() -> ChildShardTypeDef:
    return {
      ...
    }
```
